==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/lv/lang.php <==
<?php
/**
 * latvian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Aivars Miška <allefm@gmail.com>
 */
$lang['admin_acl']             = 'Piekļuves tiesību vadība';
$lang['acl_group']             = 'Grupa';
$lang['acl_user']              = 'Lietotājs';
$lang['acl_perms']             = 'Tiesības';
$lang['page']                  = 'Lapa';
$lang['namespace']             = 'Nodaļa';
$lang['p_user_id']             = 'Lietotājam <b class="acluser">%s</b> ir tiesības <i>%s</i> lapu <b class="aclpage">%s</b> .';
$lang['p_user_ns']             = 'Lietotājam <b class="acluser">%s</b> nodaļā <b class="aclns">%s</b> ir tiesības <i>%s</i>.';
$lang['p_group_id']            = 'Grupas <b class="aclgroup">%s</b> biedriem ir tiesības <i>%s</i> lapu <b class="aclpage">%s</b>.';
$lang['p_group_ns']            = 'Grupas <b class="aclgroup">%s</b> biedriem ir tiesības <i>%s</i> nodaļu  <b class="aclns">%s</b>: .';
$lang['p_choose_id']           = 'Lūdzu <b>ieraksti lietotāju vai grupu</b> augstāk norādītajā laukā, lai skatītu vai labotu tiesības lapai <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Lūdzu <b>ieraksti lietotāju vai grupu</b> augstāk norādītajā laukā, lai skatītu vai labotu tiesības nodaļai <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Ievēro: Šīs tiesības nav tieši uzdotas, bet mantotas no citām grupām vai augstākām nodaļām. ';
$lang['p_isadmin']             = 'Ievēro: Norādītajai grupai vai lietotājam vienmēr ir visas tiesības, jo tas konfigurēts kā <i>superuser</i>.';
$lang['current']               = 'Patreizējo tiesību saraksts (ACL)';
$lang['where']                 = 'Lapa/nodaļa';
$lang['who']                   = 'Lietotājs/grupa';
$lang['perm']                  = 'Tiesības';
$lang['acl_perm0']             = 'nekādas';
$lang['acl_perm1']             = 'lasīt';
$lang['acl_perm2']             = 'labot';
$lang['acl_perm4']             = 'izveidot';
$lang['acl_perm8']             = 'augšupielādēt';
$lang['acl_perm16']            = 'dzēst';
$lang['acl_new']               = 'pievienot jaunu šķirkli';
$lang['acl_mod']               = 'labot šķirkli';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/lv/lang.php <==
<?php
/**
 * latvian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Aivars Miška <allefm@gmail.com>
 */
$lang['admin_acl']             = 'Piekļuves tiesību vadība';
$lang['acl_group']             = 'Grupa';
$lang['acl_user']              = 'Lietotājs';
$lang['acl_perms']             = 'Tiesības';
$lang['page']                  = 'Lapa';
$lang['namespace']             = 'Nodaļa';
$lang['btn_select']            = 'Izvēlēties';
$lang['p_user_id']             = 'Lietotājam <b class="acluser">%s</b> ir tiesības <i>%s</i> lapu <b class="aclpage">%s</b> .';
$lang['p_user_ns']             = 'Lietotājam <b class="acluser">%s</b> nodaļā <b class="aclns">%s</b> ir tiesības <i>%s</i>.';
$lang['p_group_id']            = 'Grupas <b class="aclgroup">%s</b> biedriem ir tiesības <i>%s</i> lapu <b class="aclpage">%s</b>.';
$lang['p_group_ns']            = 'Grupas <b class="aclgroup">%s</b> biedriem ir tiesības <i>%s</i> nodaļu  <b class="aclns">%s</b>: .';
$lang['p_choose_id']           = 'Lūdzu <b>ieraksti lietotāju vai grupu</b> augstāk norādītajā laukā, lai skatītu vai labotu tiesības lapai <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Lūdzu <b>ieraksti lietotāju vai grupu</b> augstāk norādītajā laukā, lai skatītu vai labotu tiesības nodaļai <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Ievēro: Šīs tiesības nav tieši uzdotas, bet mantotas no citām grupām vai augstākām nodaļām. ';
$lang['p_isadmin']             = 'Ievēro: Norādītajai grupai vai lietotājam vienmēr ir visas tiesības, jo tas konfigurēts kā <i>superuser</i>.';
$lang['p_include']             = 'Augstāka atļauja iekļauj arī zemākās tiesības. Izveidošanas, augšupielādēšanas un dzēšanas tiesības attiecas tikai uz nodaļām, nevis lapām.';
$lang['current']               = 'Patreizējo tiesību saraksts (ACL)';
$lang['where']                 = 'Lapa/nodaļa';
$lang['who']                   = 'Lietotājs/grupa';
$lang['perm']                  = 'Tiesības';
$lang['acl_perm0']             = 'nekādas';
$lang['acl_perm1']             = 'lasīt';
$lang['acl_perm2']             = 'labot';
$lang['acl_perm4']             = 'izveidot';
$lang['acl_perm8']             = 'augšupielādēt';
$lang['acl_perm16']            = 'dzēst';
$lang['acl_new']               = 'pievienot jaunu šķirkli';
$lang['acl_mod']               = 'labot šķirkli';
